==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/compute/kotlin/inputs/LinuxVMGuestPatchAutomaticByPlatformSettingsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.compute.kotlin.inputs

import com.pulumi.azurenative.compute.inputs.LinuxVMGuestPatchAutomaticByPlatformSettingsArgs.builder
import com.pulumi.azurenative.compute.kotlin.enums.LinuxVMGuestPatchAutomaticByPlatformRebootSetting
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Specifies additional settings to be applied when patch mode AutomaticByPlatform is selected in Linux patch settings.
 * @property bypassPlatformSafetyChecksOnUserSchedule Enables customer to schedule patching without accidental upgrades
 * @property rebootSetting Specifies the reboot setting for all AutomaticByPlatform patch installation operations.
 */
public data class LinuxVMGuestPatchAutomaticByPlatformSettingsArgs(
    public val bypassPlatformSafetyChecksOnUserSchedule: Output<Boolean>? = null,
    public val rebootSetting:
    Output<Either<String, LinuxVMGuestPatchAutomaticByPlatformRebootSetting>>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.compute.inputs.LinuxVMGuestPatchAutomaticByPlatformSettingsArgs> {
    override fun toJava():
        com.pulumi.azurenative.compute.inputs.LinuxVMGuestPatchAutomaticByPlatformSettingsArgs =
        com.pulumi.azurenative.compute.inputs.LinuxVMGuestPatchAutomaticByPlatformSettingsArgs.builder()
            .bypassPlatformSafetyChecksOnUserSchedule(
                bypassPlatformSafetyChecksOnUserSchedule?.applyValue({ args0 ->
                    args0
                }),
            )
            .rebootSetting(
                rebootSetting?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            ).build()
}

/**
 * Builder for [LinuxVMGuestPatchAutomaticByPlatformSettingsArgs].
 */
@PulumiTagMarker
public class LinuxVMGuestPatchAutomaticByPlatformSettingsArgsBuilder internal constructor() {
    private var bypassPlatformSafetyChecksOnUserSchedule: Output<Boolean>? = null

    private var rebootSetting:
        Output<Either<String, LinuxVMGuestPatchAutomaticByPlatformRebootSetting>>? = null

    /**
     * @param value Enables customer to schedule patching without accidental upgrades
     */
    @JvmName("iyoqiafvxtxavpcf")
    public suspend fun bypassPlatformSafetyChecksOnUserSchedule(`value`: Output<Boolean>) {
        this.bypassPlatformSafetyChecksOnUserSchedule = value
    }

    /**
     * @param value Specifies the reboot setting for all AutomaticByPlatform patch installation operations.
     */
    @JvmName("wgxanpoaawnrmyks")
    public suspend
    fun rebootSetting(`value`: Output<Either<String, LinuxVMGuestPatchAutomaticByPlatformRebootSetting>>) {
        this.rebootSetting = value
    }

    /**
     * @param value Enables customer to schedule patching without accidental upgrades
     */
    @JvmName("bujvhpfifhspejdw")
    public suspend fun bypassPlatformSafetyChecksOnUserSchedule(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.bypassPlatformSafetyChecksOnUserSchedule = mapped
    }

    /**
     * @param value Specifies the reboot setting for all AutomaticByPlatform patch installation operations.
     */
    @JvmName("omwgiduxakofupbb")
    public suspend
    fun rebootSetting(`value`: Either<String, LinuxVMGuestPatchAutomaticByPlatformRebootSetting>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.rebootSetting = mapped
    }

    /**
     * @param value Specifies the reboot setting for all AutomaticByPlatform patch installation operations.
     */
    @JvmName("hyenvnydbkcpaxlo")
    public fun rebootSetting(`value`: String) {
        val toBeMapped = Either.ofLeft<String, LinuxVMGuestPatchAutomaticByPlatformRebootSetting>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.rebootSetting = mapped
    }

    /**
     * @param value Specifies the reboot setting for all AutomaticByPlatform patch installation operations.
     */
    @JvmName("ixdfblnykqrgtfii")
    public fun rebootSetting(`value`: LinuxVMGuestPatchAutomaticByPlatformRebootSetting) {
        val toBeMapped = Either.ofRight<String,
            LinuxVMGuestPatchAutomaticByPlatformRebootSetting,>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.rebootSetting = mapped
    }

    internal fun build(): LinuxVMGuestPatchAutomaticByPlatformSettingsArgs =
        LinuxVMGuestPatchAutomaticByPlatformSettingsArgs(
            bypassPlatformSafetyChecksOnUserSchedule = bypassPlatformSafetyChecksOnUserSchedule,
            rebootSetting = rebootSetting,
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/compute/kotlin/inputs/LinuxVMGuestPatchAutomaticByPlatformSettingsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.compute.kotlin.inputs

import com.pulumi.azurenative.compute.inputs.LinuxVMGuestPatchAutomaticByPlatformSettingsArgs.builder
import com.pulumi.azurenative.compute.kotlin.enums.LinuxVMGuestPatchAutomaticByPlatformRebootSetting
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Specifies additional settings to be applied when patch mode AutomaticByPlatform is selected in Linux patch settings.
 * @property bypassPlatformSafetyChecksOnUserSchedule Enables customer to schedule patching without accidental upgrades
 * @property rebootSetting Specifies the reboot setting for all AutomaticByPlatform patch installation operations.
 */
public data class LinuxVMGuestPatchAutomaticByPlatformSettingsArgs(
    public val bypassPlatformSafetyChecksOnUserSchedule: Output<Boolean>? = null,
    public val rebootSetting:
    Output<Either<String, LinuxVMGuestPatchAutomaticByPlatformRebootSetting>>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.compute.inputs.LinuxVMGuestPatchAutomaticByPlatformSettingsArgs> {
    override fun toJava():
        com.pulumi.azurenative.compute.inputs.LinuxVMGuestPatchAutomaticByPlatformSettingsArgs =
        com.pulumi.azurenative.compute.inputs.LinuxVMGuestPatchAutomaticByPlatformSettingsArgs.builder()
            .bypassPlatformSafetyChecksOnUserSchedule(
                bypassPlatformSafetyChecksOnUserSchedule?.applyValue({ args0 ->
                    args0
                }),
            )
            .rebootSetting(
                rebootSetting?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            ).build()
}

/**
 * Builder for [LinuxVMGuestPatchAutomaticByPlatformSettingsArgs].
 */
@PulumiTagMarker
public class LinuxVMGuestPatchAutomaticByPlatformSettingsArgsBuilder internal constructor() {
    private var bypassPlatformSafetyChecksOnUserSchedule: Output<Boolean>? = null

    private var rebootSetting:
        Output<Either<String, LinuxVMGuestPatchAutomaticByPlatformRebootSetting>>? = null

    /**
     * @param value Enables customer to schedule patching without accidental upgrades
     */
    @JvmName("vutrnghrcbefpbox")
    public suspend fun bypassPlatformSafetyChecksOnUserSchedule(`value`: Output<Boolean>) {
        this.bypassPlatformSafetyChecksOnUserSchedule = value
    }

    /**
     * @param value Specifies the reboot setting for all AutomaticByPlatform patch installation operations.
     */
    @JvmName("ttxvjvwwthdslwoa")
    public suspend
    fun rebootSetting(`value`: Output<Either<String, LinuxVMGuestPatchAutomaticByPlatformRebootSetting>>) {
        this.rebootSetting = value
    }

    /**
     * @param value Enables customer to schedule patching without accidental upgrades
     */
    @JvmName("dsultaquwrbwdlkf")
    public suspend fun bypassPlatformSafetyChecksOnUserSchedule(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.bypassPlatformSafetyChecksOnUserSchedule = mapped
    }

    /**
     * @param value Specifies the reboot setting for all AutomaticByPlatform patch installation operations.
     */
    @JvmName("chubjggplhiadntb")
    public suspend
    fun rebootSetting(`value`: Either<String, LinuxVMGuestPatchAutomaticByPlatformRebootSetting>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.rebootSetting = mapped
    }

    /**
     * @param value Specifies the reboot setting for all AutomaticByPlatform patch installation operations.
     */
    @JvmName("coxwrejhunruuqog")
    public fun rebootSetting(`value`: String) {
        val toBeMapped = Either.ofLeft<String, LinuxVMGuestPatchAutomaticByPlatformRebootSetting>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.rebootSetting = mapped
    }

    /**
     * @param value Specifies the reboot setting for all AutomaticByPlatform patch installation operations.
     */
    @JvmName("amoxlglwocrtuevo")
    public fun rebootSetting(`value`: LinuxVMGuestPatchAutomaticByPlatformRebootSetting) {
        val toBeMapped = Either.ofRight<String,
            LinuxVMGuestPatchAutomaticByPlatformRebootSetting,>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.rebootSetting = mapped
    }

    internal fun build(): LinuxVMGuestPatchAutomaticByPlatformSettingsArgs =
        LinuxVMGuestPatchAutomaticByPlatformSettingsArgs(
            bypassPlatformSafetyChecksOnUserSchedule = bypassPlatformSafetyChecksOnUserSchedule,
            rebootSetting = rebootSetting,
        )
}
